==> openjdk-src-11.0.2.u7-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_uz.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_uz extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "so\u02bbm" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Birlashgan Arab Amirliklari dirhami" },
            { "afn", "Afg\u2018oniston afg\u2018oniysi" },
            { "all", "Albaniya leki" },
            { "amd", "Armaniston drami" },
            { "ang", "Niderlandiya antil guldeni" },
            { "aoa", "Angola kvanzasi" },
            { "ars", "Argentina pesosi" },
            { "aud", "Avstraliya dollari" },
            { "awg", "Aruba florini" },
            { "azn", "Ozarbayjon manati" },
            { "bam", "Bosniya va Gertsegovina ayirboshlash markasi" },
            { "bbd", "Barbados dollari" },
            { "bdt", "Bangladesh takasi" },
            { "bgn", "Bolgariya levi" },
            { "bhd", "Bahrayn dinori" },
            { "bif", "Burundi franki" },
            { "bmd", "Bermuda dollari" },
            { "bnd", "Bruney dollari" },
            { "bob", "Boliviya bolivianosi" },
            { "brl", "Braziliya reali" },
            { "bsd", "Bagama dollari" },
            { "btn", "Butan ngultrumi" },
            { "bwp", "Botsvana pulasi" },
            { "byn", "Belarus rubli" },
            { "byr", "Belarus rubli (2000\u20132016)" },
            { "bzd", "Beliz dollari" },
            { "cad", "Kanada dollari" },
            { "cdf", "Kongo franki" },
            { "chf", "Shveytsariya franki" },
            { "clp", "Chili pesosi" },
            { "cnh", "CNH" },
            { "cny", "Xitoy yuani" },
            { "cop", "Kolumbiya pesosi" },
            { "crc", "Kosta-Rika koloni" },
            { "cuc", "Kuba ayirboshlash pesosi" },
            { "cup", "Kuba pesosi" },
            { "cve", "Kabo-Verde eskudosi" },
            { "czk", "Chexiya kronasi" },
            { "djf", "Jibuti franki" },
            { "dkk", "Daniya kronasi" },
            { "dop", "Dominikana pesosi" },
            { "dzd", "Jazoir dinori" },
            { "egp", "Misr funti" },
            { "ern", "Eritreya nakfasi" },
            { "etb", "Efiopiya biri" },
            { "eur", "Yevro" },
            { "fjd", "Fiji dollari" },
            { "fkp", "Folklend orollari funti" },
            { "gbp", "Angliya funt sterlingi" },
            { "gel", "Gruziya larisi" },
            { "ghs", "Gana sedisi" },
            { "gip", "Gibraltar funti" },
            { "gmd", "Gambiya dalasisi" },
            { "gnf", "Gvineya franki" },
            { "gtq", "Gvatemala ketsali" },
            { "gyd", "Gayana dollari" },
            { "hkd", "Gonkong dollari" },
            { "hnl", "Gonduras lempirasi" },
            { "hrk", "Xorvatiya kunasi" },
            { "htg", "Gaiti gurdi" },
            { "huf", "Vengriya forinti" },
            { "idr", "Indoneziya rupiyasi" },
            { "ils", "Isroil yangi shekeli" },
            { "inr", "Hindiston rupiyasi" },
            { "iqd", "Iroq dinori" },
            { "irr", "Eron riyoli" },
            { "isk", "Islandiya kronasi" },
            { "jmd", "Yamayka dollari" },
            { "jod", "Iordaniya dinori" },
            { "jpy", "Yaponiya iyenasi" },
            { "kes", "Keniya shillingi" },
            { "kgs", "Qirg\u2018iziston somi" },
            { "khr", "Kambodja rieli" },
            { "kmf", "Komor orollari franki" },
            { "kpw", "Shimoliy Koreya voni" },
            { "krw", "Janubiy Koreya voni" },
            { "kwd", "Kuvayt dinori" },
            { "kyd", "Kayman orollari dollari" },
            { "kzt", "Qozog\u2018iston tengesi" },
            { "lak", "Laos kipi" },
            { "lbp", "Livan funti" },
            { "lkr", "Shri-Lanka rupiyasi" },
            { "lrd", "Liberiya dollari" },
            { "ltl", "Litva liti" },
            { "lvl", "Latviya lati" },
            { "lyd", "Liviya dinori" },
            { "mad", "Marokash dirhami" },
            { "mdl", "Moldova leyi" },
            { "mga", "Malagasi ariarisi" },
            { "mkd", "Makedoniya dinori" },
            { "mmk", "Myanma kyati" },
            { "mnt", "Mongoliya tugriki" },
            { "mop", "Makao patakasi" },
            { "mro", "Mavritaniya uqiyasi (1973\u20132017)" },
            { "mru", "Mavritaniya uqiyasi" },
            { "mur", "Mavritaniya rupiyasi" },
            { "mvr", "Maldiv rupiyasi" },
            { "mwk", "Malavi kvachasi" },
            { "mxn", "Meksika pesosi" },
            { "myr", "Malayziya ringgiti" },
            { "mzn", "Mozambik metikali" },
            { "nad", "Namibiya dollari" },
            { "ngn", "Nigeriya nayrasi" },
            { "nio", "Nikaragua kordobasi" },
            { "nok", "Norvegiya kronasi" },
            { "npr", "Nepal rupiyasi" },
            { "nzd", "Yangi Zelandiya dollari" },
            { "omr", "Ummon riyoli" },
            { "pab", "Panama balboasi" },
            { "pen", "Peru soli" },
            { "pgk", "Papua \u2013 Yangi Gvineya kinasi" },
            { "php", "Filippin pesosi" },
            { "pkr", "Pokiston rupiyasi" },
            { "pln", "Polsha zlotiyi" },
            { "pyg", "Paragvay guaranisi" },
            { "qar", "Qatar riyoli" },
            { "ron", "Ruminiya leyi" },
            { "rsd", "Serbiya dinori" },
            { "rub", "Rossiya rubli" },
            { "rwf", "Ruanda franki" },
            { "sar", "Saudiya Arabistoni riyoli" },
            { "sbd", "Solomon orollari dollari" },
            { "scr", "Seyshel rupiyasi" },
            { "sdg", "Sudan funti" },
            { "sek", "Shvetsiya kronasi" },
            { "sgd", "Singapur dollari" },
            { "shp", "Muqaddas Yelena oroli funti" },
            { "sll", "Syerra-Leone leonesi" },
            { "sos", "Somali shillingi" },
            { "srd", "Surinam dollari" },
            { "ssp", "Janubiy Sudan funti" },
            { "std", "San-Tome va Prinsipi dobrasi (1977\u20132017)" },
            { "stn", "San-Tome va Prinsipi dobrasi" },
            { "syp", "Suriya funti" },
            { "szl", "Svazilend lilangenisi" },
            { "thb", "Tailand bati" },
            { "tjs", "Tojikiston somoniysi" },
            { "tmt", "Turkmaniston manati" },
            { "tnd", "Tunis dinori" },
            { "top", "Tonga paangasi" },
            { "try", "Turk lirasi" },
            { "ttd", "Trinidad va Tobago dollari" },
            { "twd", "Yangi Tayvan dollari" },
            { "tzs", "Tanzaniya shillingi" },
            { "uah", "Ukraina grivnasi" },
            { "ugx", "Uganda shillingi" },
            { "usd", "AQSH dollari" },
            { "uyu", "Urugvay pesosi" },
            { "uzs", "O\u2018zbekiston so\u2018mi" },
            { "vef", "Venesuela bolivari" },
            { "vnd", "Vyetnam dongi" },
            { "vuv", "Vanuatu vatusi" },
            { "wst", "Samoa talasi" },
            { "xaf", "Markaziy Afrika CFA franki" },
            { "xcd", "Sharqiy Karib dollari" },
            { "xof", "G\u2018arbiy Afrika CFA franki" },
            { "xpf", "Fransuz Polineziyasi franki" },
            { "xxx", "Noma\u2019lum valyuta" },
            { "yer", "Yaman riyoli" },
            { "zar", "Janubiy Afrika rendi" },
            { "zmw", "Zambiya kvachasi" },
        };
        return data;
    }
}

==> openjdk-src-13.0.2.u8-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_uz.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_uz extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "UZS", "so\u02bbm" },
            { "aed", "Birlashgan Arab Amirliklari dirhami" },
            { "afn", "Afg\u2018oniston afg\u2018oniysi" },
            { "all", "Albaniya leki" },
            { "amd", "Armaniston drami" },
            { "ang", "Niderlandiya antil guldeni" },
            { "aoa", "Angola kvanzasi" },
            { "ars", "Argentina pesosi" },
            { "aud", "Avstraliya dollari" },
            { "awg", "Aruba florini" },
            { "azn", "Ozarbayjon manati" },
            { "bam", "Bosniya va Gertsegovina ayirboshlash markasi" },
            { "bbd", "Barbados dollari" },
            { "bdt", "Bangladesh takasi" },
            { "bgn", "Bolgariya levi" },
            { "bhd", "Bahrayn dinori" },
            { "bif", "Burundi franki" },
            { "bmd", "Bermuda dollari" },
            { "bnd", "Bruney dollari" },
            { "bob", "Boliviya bolivianosi" },
            { "brl", "Braziliya reali" },
            { "bsd", "Bagama dollari" },
            { "btn", "Butan ngultrumi" },
            { "bwp", "Botsvana pulasi" },
            { "byn", "Belarus rubli" },
            { "byr", "Belarus rubli (2000\u20132016)" },
            { "bzd", "Beliz dollari" },
            { "cad", "Kanada dollari" },
            { "cdf", "Kongo franki" },
            { "chf", "Shveytsariya franki" },
            { "clp", "Chili pesosi" },
            { "cnh", "CNH" },
            { "cny", "Xitoy yuani" },
            { "cop", "Kolumbiya pesosi" },
            { "crc", "Kosta-Rika koloni" },
            { "cuc", "Kuba ayirboshlash pesosi" },
            { "cup", "Kuba pesosi" },
            { "cve", "Kabo-Verde eskudosi" },
            { "czk", "Chexiya kronasi" },
            { "djf", "Jibuti franki" },
            { "dkk", "Daniya kronasi" },
            { "dop", "Dominikana pesosi" },
            { "dzd", "Jazoir dinori" },
            { "egp", "Misr funti" },
            { "ern", "Eritreya nakfasi" },
            { "etb", "Efiopiya biri" },
            { "eur", "Yevro" },
            { "fjd", "Fiji dollari" },
            { "fkp", "Folklend orollari funti" },
            { "gbp", "Angliya funt sterlingi" },
            { "gel", "Gruziya larisi" },
            { "ghs", "Gana sedisi" },
            { "gip", "Gibraltar funti" },
            { "gmd", "Gambiya dalasisi" },
            { "gnf", "Gvineya franki" },
            { "gtq", "Gvatemala ketsali" },
            { "gyd", "Gayana dollari" },
            { "hkd", "Gonkong dollari" },
            { "hnl", "Gonduras lempirasi" },
            { "hrk", "Xorvatiya kunasi" },
            { "htg", "Gaiti gurdi" },
            { "huf", "Vengriya forinti" },
            { "idr", "Indoneziya rupiyasi" },
            { "ils", "Isroil yangi shekeli" },
            { "inr", "Hindiston rupiyasi" },
            { "iqd", "Iroq dinori" },
            { "irr", "Eron riyoli" },
            { "isk", "Islandiya kronasi" },
            { "jmd", "Yamayka dollari" },
            { "jod", "Iordaniya dinori" },
            { "jpy", "Yaponiya iyenasi" },
            { "kes", "Keniya shillingi" },
            { "kgs", "Qirg\u2018iziston somi" },
            { "khr", "Kambodja rieli" },
            { "kmf", "Komor orollari franki" },
            { "kpw", "Shimoliy Koreya voni" },
            { "krw", "Janubiy Koreya voni" },
            { "kwd", "Kuvayt dinori" },
            { "kyd", "Kayman orollari dollari" },
            { "kzt", "Qozog\u2018iston tengesi" },
            { "lak", "Laos kipi" },
            { "lbp", "Livan funti" },
            { "lkr", "Shri-Lanka rupiyasi" },
            { "lrd", "Liberiya dollari" },
            { "ltl", "Litva liti" },
            { "lvl", "Latviya lati" },
            { "lyd", "Liviya dinori" },
            { "mad", "Marokash dirhami" },
            { "mdl", "Moldova leyi" },
            { "mga", "Malagasi ariarisi" },
            { "mkd", "Makedoniya dinori" },
            { "mmk", "Myanma kyati" },
            { "mnt", "Mongoliya tugriki" },
            { "mop", "Makao patakasi" },
            { "mro", "Mavritaniya uqiyasi (1973\u20132017)" },
            { "mru", "Mavritaniya uqiyasi" },
            { "mur", "Mavritaniya rupiyasi" },
            { "mvr", "Maldiv rupiyasi" },
            { "mwk", "Malavi kvachasi" },
            { "mxn", "Meksika pesosi" },
            { "myr", "Malayziya ringgiti" },
            { "mzn", "Mozambik metikali" },
            { "nad", "Namibiya dollari" },
            { "ngn", "Nigeriya nayrasi" },
            { "nio", "Nikaragua kordobasi" },
            { "nok", "Norvegiya kronasi" },
            { "npr", "Nepal rupiyasi" },
            { "nzd", "Yangi Zelandiya dollari" },
            { "omr", "Ummon riyoli" },
            { "pab", "Panama balboasi" },
            { "pen", "Peru soli" },
            { "pgk", "Papua \u2013 Yangi Gvineya kinasi" },
            { "php", "Filippin pesosi" },
            { "pkr", "Pokiston rupiyasi" },
            { "pln", "Polsha zlotiyi" },
            { "pyg", "Paragvay guaranisi" },
            { "qar", "Qatar riyoli" },
            { "ron", "Ruminiya leyi" },
            { "rsd", "Serbiya dinori" },
            { "rub", "Rossiya rubli" },
            { "rwf", "Ruanda franki" },
            { "sar", "Saudiya Arabistoni riyoli" },
            { "sbd", "Solomon orollari dollari" },
            { "scr", "Seyshel rupiyasi" },
            { "sdg", "Sudan funti" },
            { "sek", "Shvetsiya kronasi" },
            { "sgd", "Singapur dollari" },
            { "shp", "Muqaddas Yelena oroli funti" },
            { "sll", "Syerra-Leone leonesi" },
            { "sos", "Somali shillingi" },
            { "srd", "Surinam dollari" },
            { "ssp", "Janubiy Sudan funti" },
            { "std", "San-Tome va Prinsipi dobrasi (1977\u20132017)" },
            { "stn", "San-Tome va Prinsipi dobrasi" },
            { "syp", "Suriya funti" },
            { "szl", "Svazilend lilangenisi" },
            { "thb", "Tailand bati" },
            { "tjs", "Tojikiston somoniysi" },
            { "tmt", "Turkmaniston manati" },
            { "tnd", "Tunis dinori" },
            { "top", "Tonga paangasi" },
            { "try", "Turk lirasi" },
            { "ttd", "Trinidad va Tobago dollari" },
            { "twd", "Yangi Tayvan dollari" },
            { "tzs", "Tanzaniya shillingi" },
            { "uah", "Ukraina grivnasi" },
            { "ugx", "Uganda shillingi" },
            { "usd", "AQSH dollari" },
            { "uyu", "Urugvay pesosi" },
            { "uzs", "O\u2018zbekiston so\u2018mi" },
            { "vef", "Venesuela bolivari (2008\u20132018)" },
            { "ves", "Venesuela bolivari" },
            { "vnd", "Vyetnam dongi" },
            { "vuv", "Vanuatu vatusi" },
            { "wst", "Samoa talasi" },
            { "xaf", "Markaziy Afrika CFA franki" },
            { "xcd", "Sharqiy Karib dollari" },
            { "xof", "G\u2018arbiy Afrika CFA franki" },
            { "xpf", "Fransuz Polineziyasi franki" },
            { "xxx", "Noma\u2019lum valyuta" },
            { "yer", "Yaman riyoli" },
            { "zar", "Janubiy Afrika rendi" },
            { "zmw", "Zambiya kvachasi" },
        };
        return data;
    }
}
